pub struct BlobParams {
pub target_blob_count: u64,
pub max_blob_count: u64,
pub update_fraction: u128,
pub min_blob_fee: u128,
pub max_blobs_per_tx: u64,
pub blob_base_cost: u64,
}Expand description
Configuration for the blob-related calculations.
Fields
target_blob_count: u64Target blob count for the block.
max_blob_count: u64Max blob count for the block.
update_fraction: u128Update fraction for excess blob gas calculation.
min_blob_fee: u128Minimum gas price for a data blob.
Not required per EIP-7840 and assumed to be the default
eip4844::BLOB_TX_MIN_BLOB_GASPRICE if not set.
max_blobs_per_tx: u64Maximum number of blobs per transaction.
Defaults to max_blob_count unless set otherwise.
blob_base_cost: u64Minimum execution gas required to include a blob in a block.
Defaults to 0 unless set otherwise.
Implementations
Sourceimpl BlobParams
impl BlobParams
Sourcepub const fn cancun() -> Self
pub const fn cancun() -> Self
Returns BlobParams configuration activated with Cancun hardfork.
Sourcepub const fn prague() -> Self
pub const fn prague() -> Self
Returns BlobParams configuration activated with Prague hardfork.
Sourcepub const fn osaka() -> Self
pub const fn osaka() -> Self
Returns BlobParams configuration activated with Osaka hardfork.
Sourcepub const fn bpo1() -> Self
pub const fn bpo1() -> Self
BlobParams for the EIP-7892 Blob parameter only hardfork BPO1.
Sourcepub const fn bpo2() -> Self
pub const fn bpo2() -> Self
BlobParams for the EIP-7892 Blob parameter only hardfork BPO2
Sourcepub const fn with_max_blobs_per_tx(self, max_blobs_per_tx: u64) -> Self
pub const fn with_max_blobs_per_tx(self, max_blobs_per_tx: u64) -> Self
Set max blobs per transaction on BlobParams.
Sourcepub const fn with_blob_base_cost(self, blob_base_cost: u64) -> Self
pub const fn with_blob_base_cost(self, blob_base_cost: u64) -> Self
Set blob base cost on BlobParams.
Sourcepub const fn max_blob_gas_per_block(&self) -> u64
pub const fn max_blob_gas_per_block(&self) -> u64
Returns the maximum available blob gas in a block.
This is max blob count * DATA_GAS_PER_BLOB
Sourcepub const fn target_blob_gas_per_block(&self) -> u64
pub const fn target_blob_gas_per_block(&self) -> u64
Returns the blob gas target per block.
This is target blob count * DATA_GAS_PER_BLOB
Sourcepub const fn next_block_excess_blob_gas(
&self,
excess_blob_gas: u64,
blob_gas_used: u64,
) -> u64
👎Deprecated: Use next_block_excess_blob_gas_osaka instead
pub const fn next_block_excess_blob_gas( &self, excess_blob_gas: u64, blob_gas_used: u64, ) -> u64
next_block_excess_blob_gas_osaka insteadCalculates the excess_blob_gas value for the next block based on the current block
excess_blob_gas and blob_gas_used.
Sourcepub const fn next_block_excess_blob_gas_osaka(
&self,
excess_blob_gas: u64,
blob_gas_used: u64,
base_fee_per_gas: u64,
) -> u64
pub const fn next_block_excess_blob_gas_osaka( &self, excess_blob_gas: u64, blob_gas_used: u64, base_fee_per_gas: u64, ) -> u64
Calculates the excess_blob_gas value for the next block based on the current block
excess_blob_gas, blob_gas_used and base_fee_per_gas.
Sourcepub const fn calc_blob_fee(&self, excess_blob_gas: u64) -> u128
pub const fn calc_blob_fee(&self, excess_blob_gas: u64) -> u128
Calculates the blob fee for block based on its excess_blob_gas.